/*
    Copyright 2004,2005,2006 Luigi Auriemma

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

    http://www.gnu.org/licenses/gpl.txt

*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifdef WIN32
    #include <winsock.h>
#else
    #include <arpa/inet.h>
    #include <netdb.h>
#endif



#define VER     "0.1"


char *iphalt_enc(unsigned int ip);
unsigned int iphalt_dec(char *ipenc);



int main(int argc, char *argv[]) {
    unsigned int   ip;


    setbuf(stdout, NULL);

    fputs("\n"
        "IPalt alternate number calculator and retriever "VER"\n"
        "by Luigi Auriemma\n"
        "e-mail: aluigi@autistici.org\n"
        "web:    aluigi.org\n"
        "\n", stdout);

    if(argc < 2) {
        printf("\nUsage: %s <IP_or_alternate#>\n"
            "\n"
            "Note: the tool automatically understands if your input is an IP or an IPalt alternate number\n"
            "\n", argv[0]);
        exit(1);
    }

    if(strchr(argv[1], '.')) {
        ip = ntohl(inet_addr(argv[1]));
        printf("Alternate #:   %s\n", iphalt_enc(ip));
    } else {
        ip = ntohl(iphalt_dec(argv[1]));
        printf("IP address:    %s\n", inet_ntoa(*(struct in_addr *)&ip));
    }

    return(0);
}



char *iphalt_enc(unsigned int ip) {
    static char     buff[16];
    char            *ptr;

    ptr = buff + sizeof(buff) - 1;
    *ptr = 0;
    do {
        ptr--;
        *ptr = (ip % 10) + '0';
        ip /= 10;
    } while(ip);

    return(ptr);
}



unsigned int iphalt_dec(char *ipenc) {
    unsigned int   ret = 0;

    while(*ipenc) {
        ret = (ret * 10) + (*ipenc - '0');
        ipenc++;
    }

    return(ret);
}


